"""
sentry.filters
~~~~~~~~~~~~~~

:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
:license: BSD, see LICENSE for more details.
"""

from sentry.filters.base import *
from sentry.filters.builtins import *
from sentry.filters.widgets import *

# Backwards compatibility
SentryFilter = Filter
